function [cdfoflambda, pdfoflambda, cdfofdec, pdfofdec, cdfofext, pdfofext]=DHbayes(muR, sigma2slp, sigma2muR, n, L, years, nq, ne)

dfslp=0.333 + .212*n - 0.387*L; %estimate of dfslp

%Set the uniform priors on mu and sigma2;  prior is 1 within limits and 0 outside
mumax=muR+0.01;
mumin=muR-0.01;
normconst=tcdf((muR-mumin)/sqrt(sigma2muR),round(dfslp))-tcdf((muR-mumax)/sqrt(sigma2muR),round(dfslp));
while (normconst < 0.99) %Pick a uniform prior that covers most of the plausible mu space
   mumax=mumax+0.01; 
   mumin=mumin-0.01; 
   normconst=tcdf((muR-mumin)/sqrt(sigma2muR),round(dfslp))-tcdf((muR-mumax)/sqrt(sigma2muR),round(dfslp));
end
delmu=(mumax-mumin)/100;
mulevels= mumax:-delmu:mumin; %this will be used for making matrix of joint dist of mu and sigma2p

s2min=0.0001;
s2max=sigma2slp*2;
normconst=chi2cdf(dfslp*sigma2slp/s2min,round(dfslp))-chi2cdf(dfslp*sigma2slp/s2max,round(dfslp));
while (normconst<0.99) %Pick a uniform prior that covers most of the plausible sigma2 space
   s2max=s2max*1.1; 
   normconst=chi2cdf(dfslp*sigma2slp/s2min,round(dfslp))-chi2cdf(dfslp*sigma2slp/s2max,round(dfslp));
end
delsigma2p=(s2max-s2min)/100;
s2levels = s2min:delsigma2p:s2max; %this will be used for making matrix of joint dist of mu and sigma2p

%%%Make matrix of likelihood of mu * likelihood of s2
mus2prob=zeros(length(mulevels),length(s2levels));
for i=1:length(mulevels), %rows
   mu=mulevels(i);
   mus2prob(i,:)=normpdf(muR,mu,sqrt(s2levels/(n-L))).*gampdf(sigma2slp,dfslp/2,2*s2levels/dfslp);
end
mus2normconst=sum(mus2prob(:))*delmu*delsigma2p;

%%%%%Calculate cdf of lambda
murange=log(1.2):-.01:log(.8);
cdfoflambda=[exp(murange); (1-tcdf((muR-murange)/sqrt(sigma2muR),round(dfslp)))]; %normconst=1 pretty much so just use tcdf

%%%%%Calculate pdf of lambda
murange=log(1.2):-.01:log(.8);
pdfoflambda=[exp(murange); (tpdf((muR-murange)/sqrt(sigma2muR),round(dfslp)))]; %normconst=1 pretty much so just use tcdf


%%%%%Calculate cdf of probability of decline
%Set decline
decline=10/1; %10/1 means a 10 to 1 decline
%Specify the thresholds of risk of decline to calculate for
declevels=[0:.05:.45 .55:.05:1];

%Calculate the risk (probability) of decline at end of time horizon given mu and sigma2p
%Store in a matrix for different parameter values
decmatrix=(1-normcdf( (log(decline) + mulevels*years)' * ((s2levels*years).^-0.5) ));

tmpcdf=[];
for i=declevels,
   tmpcdf=[tmpcdf sum(mus2prob(decmatrix<i)*delmu*delsigma2p)/mus2normconst];
end
cdfofdec=[declevels; tmpcdf];
del=abs(declevels(2:end)-declevels(1:(end-1)));
pdfofdec=[(cdfofdec(1,2:end)+cdfofdec(1,1:(end-1)))/2; (cdfofdec(2,2:end)-cdfofdec(2,1:(end-1)))./del];

%%%%%Calculate cdf of probability of extinction
if(nq==NaN) %no pop size est
   cdfofext=NaN;
   pdfofext=NaN;
else
   %Specify the thresholds of risk of decline to calculate for
   declevels=[0:.05:.45 .55:.05:1];
   
   %Calculate the risk (probability) of decline at end of time horizon given mu and sigma2p
   %Store in a matrix for different parameter values
   extmatrix=zeros(length(mulevels),length(s2levels));
   for i=1:length(mulevels), %rows
      mu=mulevels(i);
      tmp=2*log(nq/ne)*abs(mu)./s2levels;
      tmp=tmp/700; %this is a trick to get rid of NAs when tmp is big
      tmp(find(tmp<1))=1;
      G = normcdf( (-log(nq/ne) + abs(mu)*years)./sqrt(s2levels*years)) +...
         (exp((1./tmp).*(2*log(nq/ne)*abs(mu)./s2levels)).*...
         normcdf( (-log(nq/ne) - abs(mu)*years)./sqrt(s2levels*years)).^(1./tmp)).^tmp;
      if(mu < 0) probext = 1; else probext = (ne/nq).^(2*mu./s2levels); end
      extmatrix(i,:) = G.*probext;
   end
   
   tmpcdf=[];
   for i=declevels,
      tmpcdf=[tmpcdf sum(mus2prob(extmatrix<i)*delmu*delsigma2p)/mus2normconst];
   end
   cdfofext=[declevels; tmpcdf];
   del=abs(declevels(2:end)-declevels(1:(end-1)));
   pdfofext=[(cdfofext(1,2:end)+cdfofext(1,1:(end-1)))/2; (cdfofext(2,2:end)-cdfofext(2,1:(end-1)))./del];
   
end