figure(1) %diagnostics plot
clf

%Plot interpolated data
subplot(3,2,1)
plot(year,N,'-r');
xlabel('year');
ylabel('count');
title('Time series; missing data interpolated');
tmppos=get(gca,'Position');
tmppos(4)=.8*tmppos(4);
set(gca,'Position',tmppos);

%Test for trends in data
subplot(3,2,3)
plot(Nlogratiosyrs,Nlogratios,'or');
[a,b,c,d,stats]=regress(Nlogratios',[ones(length(Nlogratios),1) Nlogratiosyrs']);
trendpvalue=stats(3);
title(['p.value for trend test:' num2str(trendpvalue)])
xlabel('year');
ylabel('ln(N_{t+1}/N_t)');
tmppos=get(gca,'Position');
tmppos(4)=.8*tmppos(4);
set(gca,'Position',tmppos);

%check for normality
subplot(3,2,4)
normplot(Nlogratios)
tmppos=get(gca,'Position');
tmppos(4)=.8*tmppos(4);
set(gca,'Position',tmppos);

%%%%%Estimate mu, sigma2p, sigma2np, and sigma2muR
%get mu; use the trimmed mean which is more resistant to outliers
muR=trimmean(Rlogratios,10);
muD=trimmean(Nlogratios,10);

%Get sigma2p using slope of variance versus tau
%This uses var(tmp) which is sensitive to outliers, but the mad(x) is inefficient and data are
%often limited.  But if normality problems are evident and data are sufficient, try (1.3*mad(tmp))^2 as a variance estimator
taumax=3;  %4 works fine too
varrunsums=[];
for i=1:taumax,
   tmp = log(runsum((i+1):runlen))-log(runsum(1:(runlen-i)));
   varrunsums = [varrunsums var(tmp)];
end

%Get variance slope by linear regression
%alternatively you can use just the first and last points: sigma2slp=(varrunsums(4)-varrunsums(1))/3
[a b c d stats]=regress(varrunsums',[ones(taumax,1) (1:taumax)']);
stats=stats(1);
sigma2slp=a(2);

%If sigma2slp is basically 0, can get sigma2<0 if answer should really
%be sigma2=0; check and replace if applicable
comment=' ';
if (sigma2slp < 0 & stats > .9) 
   comment='Sigma2slp less than 0 and not zero';
end 
if (sigma2slp < 0 & stats < .9) 
   sigma2slp=0.00001; 
   comment='Replaced neg sigma2slp with 1E-5';
end

%Get sigma2np
sigma2np=(var(Nlogratios)-sigma2slp)/2;

%Get sigma2muR
sigma2muR=(2*sigma2np/filtlen + (lenN-filtlen)*sigma2slp)/(lenN-filtlen)^2;

%Get Dennis estimate sigma2
sigma2D=var(Nlogratios);

%Get dfslp estimate
dfslp=0.333 + .212*lenN - 0.387*filtlen; %estimate of dfslp

params=[muR muD sigma2slp sigma2np sigma2muR sigma2D dfslp lenN filtlen];

%Print out params on plot
subplot(3,2,2)
set(gca,'Visible','off','XLim',[0 1],'YLim',[0 1]);
str(1)={'Dennis-Holmes Estimates'};
str(2)={' '};
str(3)={['mean \mu_R = ' num2str(muR,3) '  \sigma^2_{\mu} = ' num2str(sigma2muR,3)]};
str(4)={' '};
str(5)={['mean \sigma^2_{np} = ' num2str(sigma2np,3)]};
str(6)={' '};
str(7)={['mean \sigma^2_p = ' num2str(sigma2slp,3) ' biased']};
str(8)={' '};
str(9)={['n = ' num2str(lenN) '  df_{slp} = ' num2str(dfslp,2) '   filtlen = ' num2str(filtlen,0)]};
text(0,.5,str,'FontSize',8);

%%%%%Plot posterior distributions of mu and sigma2p given estimates from Dennis-Holmes and Dennis methods

%%%%%Plot posterior distribution of mu using DH parameters
murange=-.5:0.025:.5; %This is the default range over which the post. dist. will be plotted

%Set the uniform priors on mu;  prior is 1 within limits and 0 outside
mumax=muR+0.2;
mumin=muR-0.2;
normconst=tcdf((muR-mumin)/sqrt(sigma2muR),round(dfslp))-tcdf((muR-mumax)/sqrt(sigma2muR),round(dfslp));
while (normconst < 0.99) %Pick a uniform prior that covers most of the plausible mu space
   mumax=mumax+0.01; 
   mumin=mumin-0.01; 
   normconst=tcdf((muR-mumin)/sqrt(sigma2muR),round(dfslp))-tcdf((muR-mumax)/sqrt(sigma2muR),round(dfslp));
end

%Set up the murange interactively in case reasonable range is much smaller than default
muDHrange=murange;
if(mumax<max(murange)) muDHrange=min(murange):(mumax-min(murange))/50:mumax; end
if(mumin>min(murange)) muDHrange=mumin:(max(muDHrange)-mumin)/50:max(muDHrange); end

pdfofmu=[];
normconst=tcdf((muR-mumin)/sqrt(sigma2muR),round(dfslp))-tcdf((muR-mumax)/sqrt(sigma2muR),round(dfslp));
for mu=muDHrange,
   pdfofmu=[pdfofmu tpdf((muR-mu)/sqrt(sigma2muR),round(dfslp))/normconst];
end

if(DennisCompare==1)   %%%%%Plot posterior distribution of mu using Dennis parameters
	%Set the uniform priors on mu;  prior is 1 within limits and 0 outside
	mumax=muD+0.2;
   mumin=muD-0.2;
   dfD=length(Nlogratios)-1;
	normconst=tcdf((muD-mumin)/sqrt(sigma2D/dfD),round(dfD))-tcdf((muD-mumax)/sqrt(sigma2D/dfD),round(dfD));
	while (normconst < 0.99) %Pick a uniform prior that covers most of the plausible mu space
   		mumax=mumax+0.01; 
   		mumin=mumin-0.01; 
		normconst=tcdf((muD-mumin)/sqrt(sigma2D/dfD),round(dfD))-tcdf((muD-mumax)/sqrt(sigma2D/dfD),round(dfD));
	end
   
   %Set up the murange interactively in case reasonable range is much smaller than default
   muDrange=murange;
   if(mumax<max(murange)) muDrange=min(murange):(mumax-min(murange))/50:mumax; end
   if(mumin>min(murange)) muDrange=mumin:(max(muDrange)-mumin)/50:max(muDrange); end
   
	pdfofmuD=[];
	normconst=tcdf((muD-mumin)/sqrt(sigma2D/dfD),round(dfD))-tcdf((muD-mumax)/sqrt(sigma2D/dfD),round(dfD));
	for mu=muDrange,
		pdfofmuD=[pdfofmuD tpdf((muD-mu)/sqrt(sigma2D/dfD),round(dfD))/normconst];
	end
end

subplot(3,2,5)
if(DennisCompare==0) plot(muDHrange,pdfofmu,'-r'); %only plot DH method
else
   plot(muDHrange,pdfofmu,'-r',muDrange,pdfofmuD,':b')
   legend('DH','D',0)
end
set(gca,'XLim',[-.5 .5])
xlabel('\mu');
ylabel('Prob. Density')
title('Posterior Distribution of \mu');
tmppos=get(gca,'Position');
tmppos(4)=.8*tmppos(4);
set(gca,'Position',tmppos);

%%%%%Plot posterior distribution of sigma2p using DH parameters
s2range=0.0001:0.025:2; %This is the range over which the post. dist. will be plotted

%Set the uniform priors on mu and s2p;  prior is 1 within limits and 0 outside
s2min=0.0001;
s2max=sigma2slp*2;
normconst=chi2cdf(dfslp*sigma2slp/s2min,round(dfslp))-chi2cdf(dfslp*sigma2slp/s2max,round(dfslp));
while (normconst<0.99) %Pick a uniform prior that covers most of the plausible sigma2 space
   s2max=s2max*1.2; 
   normconst=chi2cdf(dfslp*sigma2slp/s2min,round(dfslp))-chi2cdf(dfslp*sigma2slp/s2max,round(dfslp));
end

%Set up the s2range interactively in case reasonable range is much smaller than default
s2DHrange=s2range;
if(s2max<max(s2range)) s2DHrange=min(s2range):(s2max-min(s2range))/80:s2max; end
if(s2min>min(s2range)) s2DHrange=s2min:(max(s2DHrange)-s2min)/80:max(s2DHrange); end

pdfofs2=[];
normconst=chi2cdf(dfslp*sigma2slp/s2min,round(dfslp))-chi2cdf(dfslp*sigma2slp/s2max,round(dfslp));
for s2=s2DHrange, 
   pdfofs2=[pdfofs2 gampdf(sigma2slp,dfslp/2,2*s2/dfslp)/normconst];
end

if(DennisCompare==1)
   %%%%%Plot posterior distribution of sigma2p using Dennis parameters
	%Set the uniform priors on mu and s2p;  prior is 1 within limits and 0 outside
	s2min=0.0001;
	s2max=sigma2D*2;
	normconst=chi2cdf(dfD*sigma2D/s2min,round(dfD))-chi2cdf(dfD*sigma2D/s2max,round(dfD));
   while (normconst<0.99) %Pick a uniform prior that covers most of the plausible sigma2 space
      s2max=s2max*1.2; 
		normconst=chi2cdf(dfD*sigma2D/s2min,round(dfD))-chi2cdf(dfD*sigma2D/s2max,round(dfD));
	end
   
   %Set up the s2range interactively in case reasonable range is much smaller than default
   s2Drange=s2range;
   if(s2max<max(s2range)) s2Drange=min(s2range):(s2max-min(s2range))/80:s2max; end
   if(s2min>min(s2range)) s2Drange=s2min:(max(s2Drange)-s2min)/80:max(s2Drange); end
   
   pdfofs2D=[];
	normconst=chi2cdf(dfD*sigma2D/s2min,round(dfD))-chi2cdf(dfD*sigma2D/s2max,round(dfD));
   for s2=s2Drange, %don't integrate bigger region since it'll take forever
		pdfofs2D=[pdfofs2D gampdf(sigma2D,dfD/2,2*s2/dfD)/normconst];
	end
end

subplot(3,2,6)
if(DennisCompare==0) 
   plot(s2DHrange,pdfofs2,'-r');
	set(gca,'XLim',[0 max(s2DHrange)])
else
   plot(s2DHrange,pdfofs2,'-r',s2Drange,pdfofs2D,':b')
	set(gca,'XLim',[0 max(max(s2Drange), max(s2DHrange))])
   legend('DH','D',0)
end
xlabel('\sigma^2_p');
ylabel('Prob. Density')
title('Posterior Distribution of \sigma^2_p');
tmppos=get(gca,'Position');
tmppos(4)=.8*tmppos(4);
set(gca,'Position',tmppos);

%Put title at the top of the whole graph
h=axes('Position',[0 0 1 1],'Visible','off');
text(.5,.98,[dataname ' ' num2str(minyear) '-' num2str(maxyear)],'HorizontalAlignment','center','FontSize',16)

set(gcf,'PaperPosition',[.5 1 7.5 9]);