
%Set-up and write info to output file
%Stock, ESU, Species
fprintf(fid,'%s\t%s\t%s\t',dataname, esu, 'species'); 
%'mu','sigma2','lambda', 'lamup95', 'lamlow95'
fprintf(fid,'%2.3f\t%1.3f\t%2.2f\t%2.2f\t%2.2f\t',muR, sigma2slp, exp(muR), exp(muR+tinv(.025,dfslp)*sqrt(sigma2muR)), exp(muR+tinv(.975,dfslp)*sqrt(sigma2muR)));

%Get probabilities of extinction
%'extprob24','extprob48','extprob100',
if(isnan(currentpopest))
   fprintf(fid,'%d\t%d\t%d\t',-99,-99,-99);
else
   nq=currentpopest;
   ne=quasiextlevel;
   years=[24 48 100];
   tmp=2*log(nq/ne)*abs(muR)/sigma2slp;
   tmp=tmp/700; %this is a trick to get rid of NAs when tmp is big
   if(tmp<1) tmp=1; end
   G = normcdf( (-log(nq/ne) + abs(muR)*years)./sqrt(sigma2slp*years)) +...
      (exp((1/tmp)*(2*log(nq/ne)*abs(muR)/sigma2slp))*...
      normcdf( (-log(nq/ne) - abs(muR)*years)./sqrt(sigma2slp*years)).^(1/tmp)).^tmp;
   if(muR < 0) probext = 1; else probext = (ne/nq)^(2*muR/sigma2slp); end
   probs = G*probext;
   fprintf(fid,'%d\t%d\t%d\t',probs);
end  

%Get probabilities of 2 to 1 decline
%'dec50at24', 'dec50at48','dec50at100'
probs=1-normcdf((log(2/1) + muR*[24 48 100])./sqrt(sigma2slp*[24 48 100]));
fprintf(fid,'%1.2f\t%1.2f\t%1.2f\t',probs);

%Get probabilities of 10 to 1 decline
%'dec90at24','dec90at48','dec90at100'
probs=1-normcdf((log(10/1) + muR*[24 48 100])./sqrt(sigma2slp*[24 48 100]));
fprintf(fid,'%1.2f\t%1.2f\t%1.2f\t',probs);

%Get Percent Lambda increase needed to prevent extinction
%'PercLPrevExt24at05','PercLPrevExt24at01','PercLPrevExt48at05', 'PercLPrevExt48at01', 'PercLPrevExt100at05','PercLPrevExt100at01'
percents=[-99 -99 -99 -99 -99 -99];
if(~isnan(currentpopest))
   nq=currentpopest;
   ne=quasiextlevel;
   years=[24 48 100];
   kstep=.005;
   for (k=0:20000),
      muinc=muR+log(1+k*kstep);
      tmp=2*log(nq/ne)*abs(muR)/sigma2slp;
      tmp=tmp/700; %this is a trick to get rid of NAs when tmp is big
      if(tmp<1) tmp=1; end
      G = normcdf( (-log(nq/ne) + abs(muinc)*years)./sqrt(sigma2slp*years)) +...
         (exp((1/tmp)*(2*log(nq/ne)*abs(muinc)/sigma2slp))*...
         normcdf( (-log(nq/ne) - abs(muinc)*years)./sqrt(sigma2slp*years)).^(1/tmp)).^tmp;
      if(muR < 0) probext = 1; else probext = (ne/nq)^(2*muinc/sigma2slp); end
      tmpcalcs = G*probext;
      if (percents(1)==-99 & tmpcalcs(1)<.05) percents(1)=100*k*kstep; end
      if (percents(2)==-99 & tmpcalcs(1)<.01) percents(2)=100*k*kstep; end
      if (percents(3)==-99 & tmpcalcs(2)<.05) percents(3)=100*k*kstep; end
      if (percents(4)==-99 & tmpcalcs(2)<.01) percents(4)=100*k*kstep; end
      if (percents(5)==-99 & tmpcalcs(3)<.05) percents(5)=100*k*kstep; end
      if (percents(6)==-99 & tmpcalcs(3)<.01) percents(6)=100*k*kstep; end
      if (sum(percents==-99)==0) break; end
   end
end
fprintf(fid,'%3.2f\t%3.2f\t%3.2f\t%3.2f\t%3.2f\t%3.2f\t',percents);

%Get Percent Lambda increase needed to prevent 90% decline
%'PercLPrev90dec24at05','PercLPrev90dec4at01','PercLPrev90dec48at05', 'PercLPrev90dec48at01', 'PercLPrev90dec100at05','PercLPrev90dec100at01'
percents=[-99 -99 -99 -99 -99 -99];
kstep=.005;
for (k=0:20000),
   muinc=muR+log(1+k*kstep);
   tmpcalcs=1-normcdf((log(10/1) + muinc*[24 48 100])./sqrt(sigma2slp*[24 48 100]));
   if (percents(1)==-99 & tmpcalcs(1)<.05) percents(1)=100*k*kstep; end
   if (percents(2)==-99 & tmpcalcs(1)<.01) percents(2)=100*k*kstep; end
   if (percents(3)==-99 & tmpcalcs(2)<.05) percents(3)=100*k*kstep; end
   if (percents(4)==-99 & tmpcalcs(2)<.01) percents(4)=100*k*kstep; end
   if (percents(5)==-99 & tmpcalcs(3)<.05) percents(5)=100*k*kstep; end
   if (percents(6)==-99 & tmpcalcs(3)<.01) percents(6)=100*k*kstep; end
   if (sum(percents==-99)==0) break; end
end
fprintf(fid,'%3.2f\t%3.2f\t%3.2f\t%3.2f\t%3.2f\t%3.2f\t',percents);

%Misc. stuff to print
%'nq','taumax','R2', 'fitsigma', 'comments'
fprintf(fid,'%d\t%d\t%2.2f\t%d\t%s\r',currentpopest,4,stats,-99,comment);

