figure(2) %risk metric plot
clf

if(popfilt==-99) currentpopest=NaN;
elseif(length(N)<length(popfilt)) 
   disp([dataname ' not enough data for pop size estimate']); 
   currentpopest=NaN;
else
   popests=filter(popfilt,1,N);
   currentpopest=popests(end);
end
[cdfoflambda, pdfoflambda, cdfofdec, pdfofdec, cdfofext, pdfofext]=DHbayes(muR, sigma2slp, sigma2muR, lenN, filtlen, risktimehorizon, currentpopest, quasiextlevel);

mediandecest=(1-normcdf( (log(10/1) + muR*risktimehorizon) * ((sigma2slp*risktimehorizon).^-0.5) ));
if(currentpopest~=NaN)
   nq=currentpopest;
   ne=quasiextlevel;
   years=risktimehorizon;
   tmp=2*log(nq/ne)*abs(muR)/sigma2slp;
   tmp=tmp/700; %this is a trick to get rid of NAs when tmp is big
   if(tmp<1) tmp=1; end
   G = normcdf( (-log(nq/ne) + abs(muR)*years)/sqrt(sigma2slp*years)) +...
      (exp((1/tmp)*(2*log(nq/ne)*abs(muR)/sigma2slp))*...
      normcdf( (-log(nq/ne) - abs(muR)*years)/sqrt(sigma2slp*years))^(1/tmp))^tmp;
   if(muR < 0) probext = 1; else probext = (ne/nq)^(2*muR/sigma2slp); end
   medianextprob = G*probext;
else medianextprob=NaN;
end

%Print out params on plot
subplot(3,2,5)
set(gca,'Visible','off','XLim',[0 1],'YLim',[0 1]);
str(1)={'DH Risk Estimates'};
str(2)={' '};
medianlambda=exp(muR);
str(3)={['median \lambda (exp(\mu)) = ' num2str(medianlambda,3)]};
str(4)={' '};
str(5)={['median P_{90} = ' num2str(mediandecest,3)]};
str(6)={[' ']};
str(7)={['median P_{ext} = ' num2str(medianextprob,3)]};
str(8)={['Latest pop size est = ' num2str(currentpopest)]};
str(9)={[' ']};
str(10)={['time series length = ' num2str(lenN)]};
text(0,.5,str,'FontSize',10);

%Plot interpolated data
subplot(3,2,1)
plot(year,N,'-r');
xlabel('year');
ylabel('count');
title('Time series; missing data interpolated');
tmppos=get(gca,'Position');
tmppos(4)=.8*tmppos(4);
set(gca,'Position',tmppos);

%Plot ratio data
subplot(3,2,3)
plot(Nlogratiosyrs,Nlogratios,'or');
title(['N log ratios'])
xlabel('year');
ylabel('ln(N_{t+1}/N_t)');
tmppos=get(gca,'Position');
tmppos(4)=.8*tmppos(4);
set(gca,'Position',tmppos);

%Plot pdf of lambda=exp(mu)
subplot(3,2,2)
plot(pdfoflambda(1,:),pdfoflambda(2,:),'-r')
set(gca,'XLim',[min(pdfoflambda(1,:)) max(pdfoflambda(1,:))]); 
xlabel('true \lambda');
ylabel('PDF')
title('DH Post. PDF of \lambda');
tmppos=get(gca,'Position');
tmppos(4)=.8*tmppos(4);
set(gca,'Position',tmppos);

%Plot pdf of probability of 90% decline
subplot(3,2,4)
plot(pdfofdec(1,:),pdfofdec(2,:),'-r')
xlabel('Prob. of 90% decline');
ylabel('PDF')
title(['DH Post. PDF of Prob. of 90% Decline in ' num2str(risktimehorizon) ' Yrs']);
tmppos=get(gca,'Position');
tmppos(4)=.8*tmppos(4);
set(gca,'Position',tmppos);
set(gca,'XLim',[0 1])
text(mediandecest, 0,'median','Rotation',90);

%Plot pdf of probability of extinction
if(~isnan(currentpopest))
   subplot(3,2,6)
   plot(pdfofext(1,:),pdfofext(2,:),'-r')
   xlabel('Prob. of extinction');
   ylabel('PDF')
   title(['DH Post. PDF of Prob. of Extinction in ' num2str(risktimehorizon) ' Yrs']);
   tmppos=get(gca,'Position');
   tmppos(4)=.8*tmppos(4);
   set(gca,'Position',tmppos);
   set(gca,'XLim',[0 1])
   text(medianextprob, 0,'median','Rotation',90);
end

%Put title at the top of the whole graph
h=axes('Position',[0 0 1 1],'Visible','off');
text(.5,.98,[dataname ' ' num2str(minyear) '-' num2str(maxyear)],'HorizontalAlignment','center','FontSize',16)

set(gcf,'PaperPosition',[.5 1 7.5 9]);