function [MLmuest,MLsigma2est,MLsigma2npest,,negloglik]=kalman_ests(data)
Nratios = N(2:end)./N(1:(end-1));
Nratios = Nratios( Nratios > 0 );
Nratios = log(Nratios);

muinit = mean(Nratios);
sigma2init = 0.5 * var(Nratios);
sigma2npinit = 0.5 * var(Nratios);
myopt=optimset('Display','off');

%next for lines are to properly deal with missing data so that kalman filter knows they are missing
tmp = N;
tmp(N==-99) = 1;
y = log(tmp);
y(N==-99) = -99;

a=fminsearch('kalman_loglik',[muinit log(max(0.0001,sigma2init)) log(max(0.0001,sigma2npinit))] ,myopt,y,log(N(1)),max(0.0001,sigma2init)+max(0.0001,sigma2npinit) );

MLmuest=a(1);
MLsigma2est=exp(a(2));
MLsigma2npest=exp(a(3));

negloglik = kalman_loglik( a,y,log(N(1)),max(0.0001,sigma2init)+max(0.0001,sigma2npinit) );

function negloglik = kalman_loglik(v,y,initx,V1)
%STEP 1 set the initial estimates
%Initialize by getting D-H estimates
T=length(y);
B = v(1); %mu
Q = exp(v(2)); %s2
R = exp(v(3)); %s2np
%STEP 2 using these initial estimates generate an estimate of x(t)
%using a forward pass of the Kalman filter.  This gives
%you the ML estimate of x(t) given y(1:T) and the parameter estimates.

%initialize
xtt=zeros(1,T);  Vtt=zeros(1,T); 
xtt1=zeros(1,T); Vtt1=zeros(1,T);    
Ft=zeros(1,T); vt=zeros(1,T);
At = zeros(1,T);

%set up for missing values
At(y ~= -99) = 1;
At(y == -99) = 0;
y(y == -99) = 0;

%forward pass gets you E[x(t) given y(1:t)]
x10=initx;  
V10=V1; 
for(t=1:T)
   if(t==1)
   	xtt1(1) = initx; %denotes x_1^0
      Vtt1(1) = V1; %denotes V_1^0
   else
      xtt1(t) = xtt(t-1) + B; %xtt1 denotes x_t^(t-1); Harvey 3.2.2a
      Vtt1(t) = Vtt(t-1) + Q; %Harvey 3.2.2b
   end
   Kt = Vtt1(t)*At(t)/(At(t)*Vtt1(t)*At(t)+R);
   Ft(t) = At(t)*Vtt1(t)*At(t)+R;
   vt(t) = y(t)-At(t)*xtt1(t);
   xtt(t) = xtt1(t) + Kt*( y(t) - At(t)*xtt1(t) ); %Harvey 3.2.3a
   Vtt(t) = Vtt1(t)*(1 - Kt*At(t)); %Harvey 3.3.3b
end
KT = Kt;

%Calculate negative log likelihood
negloglik =  (1/2)*sum(vt.^2./Ft) + (1/2)*sum(At.*log(abs(Ft))) + (T/2)*log(2*pi);

